@@ -59,7 +59,8 @@ class MYSQLExporter(Result):
         if not self.args.mysql: return
         import MySQLdb
         if self.args.get_only_ff:
-            aq="update tw_user set tw_id=\'%s\', task_status=1 where name=\'%s\'"
+            print "Just updating..."
+            aq="update tw_user set task_status='%s' where tw_id=\'%s\';"
         else:
             print "Getting user data"
             aq= "update tw_user set tw_id=\'%s\', task_status=\'%s\', task_host=\'%s\', created_at=\'%s\', statuses_count=\'%s\', friend_count=\'%s\', followers_count=\'%s\', geo_lat=\'%s\', geo_long=\'%s\', geo_text=\'%s\' where  name=\'%s\'" ,
@@ -196,7 +197,7 @@ class ResultsGenerator(object):
                         pass
                 else:
                     try:
-                        myusers.append( [ id_ , 2 ] )
+                        myusers.append( [ 2, id_ ] )
                     except Exception, e:
                         print e
 
